========================
``psyclone.psyir.tools``
========================

.. automodule:: psyclone.psyir.tools

   .. contents::
      :local:


Submodules
==========

.. toctree::

   psyclone.psyir.tools.dependency_tools

.. currentmodule:: psyclone.psyir.tools


Classes
=======

- :py:class:`DTCode`:
  A simple enum to store the various info, warning and error

- :py:class:`DependencyTools`:
  This class provides some useful dependency tools, allowing a user to


.. autoclass:: DTCode
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: DTCode
      :parts: 1

.. autoclass:: DependencyTools
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: DependencyTools
      :parts: 1
